IonError

Enum IonError 

#[non_exhaustive]
pub enum IonError { Io(IoError), Incomplete(IncompleteError), Encoding(EncodingError), Decoding(DecodingError), IllegalOperation(IllegalOperation), Conversion(ConversionError), }
Represents the different types of high-level failures that might occur when reading Ion data.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Io(IoError)

Indicates that an IO error was encountered while reading or writing.



Incomplete(IncompleteError)

Indicates that the input buffer did not contain enough data to perform the requested read operation. If the input source contains more data, the reader can append it to the buffer and try again.



Encoding(EncodingError)

Indicates that the writer encountered a problem while serializing a given piece of data.



Decoding(DecodingError)

Indicates that the data stream being read contained illegal or otherwise unreadable data.



IllegalOperation(IllegalOperation)

Returned when the user has performed an illegal operation (for example: calling stepOut() on the cursor at the top level.)



Conversion(ConversionError)

Returned when the user has attempted to convert a value to a type for which that value is not trivially convertable.