pub enum IonType {
Show 13 variants
Null,
Bool,
Int,
Float,
Decimal,
Timestamp,
Symbol,
String,
Clob,
Blob,
List,
SExp,
Struct,
}Expand description
Represents the Ion data type of a given value. To learn more about each data type, read the Ion Data Model section of the spec.
Variants
Implementations