ConversionOperationError

Struct ConversionOperationError 

pub struct ConversionOperationError<FromType, ToType> { /* private fields */ }
Represents a mismatch during conversion between the expected type and the actual value’s type; Holds the original value that was not able to be converted.

Implementations

Source

impl<FromType, ToType> ConversionOperationError<FromType, ToType>

pub fn new(input_value: FromType) -> Self

pub fn original_value(self) -> FromType