SourceLocation

Struct SourceLocation 

pub struct SourceLocation { /* private fields */ }
Represents the source location (row, column) of this element in the original Ion text.

The source location metadata is primarily intended for error reporting and debugging purposes, helping applications provide meaningful feedback to users about the source of issues.

Implementations

Source

impl SourceLocation

pub fn row_column(&self) -> Option<(usize, usize)>

If this SourceLocation instance has row-column information, returns a tuple containing the 1-based row and column numbers. Otherwise, returns None.

pub fn row(&self) -> Option<usize>

If this SourceLocation instance has row-column information, returns the 1-based row number. Otherwise, returns None.

pub fn column(&self) -> Option<usize>

If this SourceLocation instance has row-column information, returns the 1-based column number. Otherwise, returns None.