Struct

Struct Struct 

pub struct Struct { /* private fields */ }
An in-memory representation of an Ion Struct

use ion_rs::{Element, ion_struct};
let struct_ = ion_struct! {
  "foo": 1,
  "bar": true,
  "baz": "hello"
};
assert_eq!(struct_.len(), 3);
assert_eq!(struct_.get("baz"), Some(&Element::string("hello")));

Implementations

Source

impl Struct

pub fn builder() -> StructBuilder

pub fn clone_builder(&self) -> StructBuilder

pub fn fields(&self) -> impl Iterator<Item = (&Symbol, &Element)>

Returns an iterator over the field name/value pairs in this Struct.

pub fn len(&self) -> usize

Returns the number of fields in this Struct.

pub fn is_empty(&self) -> bool

Returns true if this struct has zero fields.

pub fn iter(&self) -> FieldIterator<'_>

pub fn get<A: AsSymbolRef>(&self, field_name: A) -> Option<&Element>

Returns the value associated with the specified field name.

If more than one field in this struct has that name, this method will return the value of the last field with that name. To access other fields with the same name, see get_all.

pub fn get_all<A: AsSymbolRef>( &self, field_name: A, ) -> impl Iterator<Item = &Element>

Returns an iterator over all of the values associated with the specified field name.