pub struct Symbol { /* private fields */ }Expand description
The text of a fully resolved field name, annotation, or symbol value. If the symbol has known
text (that is: the symbol is not $0), it will be stored as either a String or a shared
reference to text in a symbol table.
Implementations