Decimal

Struct Decimal 

pub struct Decimal { /* private fields */ }
An arbitrary-precision Decimal type with a distinct representation of negative zero (-0).

A Decimal can be thought of as a (coefficient, exponent) pair, and its value can be calculated using the formula coefficient * 10^exponent.

use ion_rs::{Int, Decimal, UInt};
use ion_rs::decimal::Sign;
// Equivalent to: 1225 * 10^-2, or 12.25
let decimal = Decimal::new(1225, -2);
// The coefficient can be viewed as a sign/magnitude pair...
assert_eq!(decimal.coefficient().sign(), Sign::Positive);
assert_eq!(decimal.coefficient().magnitude(), UInt::from(1225u64));
// ...or, if it is not negative zero, by converting it into an Int.
let coefficient: Int = decimal.coefficient().try_into().expect("`decimal` is not negative zero");
assert_eq!(coefficient, Int::from(1225));

assert_eq!(decimal.exponent(), -2);

Implementations

Source

impl Decimal

pub const ZERO: Decimal

pub const NEGATIVE_ZERO: Decimal

pub fn new<C: Into<Coefficient>, E: Into<i64>>( coefficient: C, exponent: E, ) -> Decimal

Constructs a new Decimal with the provided components. The value of the decimal is: coefficient * 10^exponent

pub fn coefficient(&self) -> Coefficient

Returns this Decimal’s coefficient.

pub fn exponent(&self) -> i64

Returns this Decimal’s exponent.

pub fn scale(&self) -> i64

Returns scale of the Decimal value If zero or positive, a scale indicates the number of digits to the right of the decimal point. If negative, the unscaled value of the number is multiplied by ten to the power of the negation of the scale. For example, a scale of -3 means the unscaled value is multiplied by 1000.

pub fn precision(&self) -> u64

Returns the number of digits in the non-scaled integer representation of the decimal.

pub fn negative_zero() -> Decimal

Constructs a Decimal with the value -0d0. This is provided as a convenience method because Rust will ignore a unary minus when it is applied to an zero literal (-0).

pub fn negative_zero_with_exponent(exponent: i64) -> Decimal

Constructs a Decimal with a coefficient of -0 and the specified exponent. This function is provided as a convenience method because Rust will ignore a unary minus when it is applied to a zero literal (-0).

pub fn is_zero(&self) -> bool

Returns true if this Decimal is a zero of any sign or exponent.

pub fn is_less_than_zero(&self) -> bool

Returns true if this Decimal’s coefficient has a negative sign AND a magnitude greater than zero. Otherwise, returns false. (Negative zero returns false.)

pub fn trunc(&self) -> Decimal

Returns the integer part of self. This means that non-integer numbers are always truncated towards zero, maintaining the sign of the original coefficient.

pub fn fract(&self) -> Decimal

Returns the fractional part of self. Values with no fractional component will return zero maintaining the sign of the original coefficient.