pub struct SourceLocation { /* private fields */ }Expand description
Represents the source location (row, column) of this element in the original Ion text.
The source location metadata is primarily intended for error reporting and debugging purposes, helping applications provide meaningful feedback to users about the source of issues.
Implementations
Sourceimpl SourceLocation
impl SourceLocation
Sourcepub fn row_column(&self) -> Option<(usize, usize)>
pub fn row_column(&self) -> Option<(usize, usize)>
If this SourceLocation instance has row-column information, returns a tuple containing
the 1-based row and column numbers. Otherwise, returns None.